@@ -13,6 +13,17 @@ sub index : Path : Args(0) {
     $c->res->body('index');
 }
 
+sub exempt_path_name : Local : Args(0) {
+    my ($self, $c) = @_;
+
+    $c->res->body('exempt_path_namel response');
+}
+
+sub exempt_foo : Path('/all_exempt/foo') : Args(0) {
+    my ($self, $c) = @_;
+
+    $c->res->body('exempt_url response');
+}
 sub upload : Local : Args(0) {
     my ($self, $c) = @_;
     $c->res->body("Uploaded file content: " . $c->req->upload('myfile')->slurp);
