@@ -10,13 +10,20 @@ extends 'Catalyst';
 __PACKAGE__->config(
     name     => 'MyApp03',
     scrubber => {
-        ignore_params => [
-            qr/_html$/,
-            'ignored_param',
-        ],
-    },
-);
-__PACKAGE__->setup();
 
+        auto => 1,
+
+        ignore_params => [ qr/_html$/, 'ignored_param' ],
+
+        # params for HTML::Scrubber
+        params => [
+            allow => [qw/br hr b/],
+        ],
+    }
+);
+
+
+
+__PACKAGE__->setup();
 1;
 
